@@ -5,7 +5,7 @@ Created on Wed Jan  5 16:45:12 2022
 @author: Tommaso
 """
 import torch
-from deep_b_spline_approximation.preprocessing import computeSegmentation,computeSampling,computeSegmentsNormalization,computeSegmentsParametrization,computeRefinement2,computeTrainingSetComplexity
+from .preprocessing import computeSegmentation,computeSampling,computeSegmentsNormalization,computeSegmentsParametrization,computeRefinement2,computeTrainingSetComplexity
 from loadfromtxt import loadFlatDataset
 from ppn import PointParametrizationNetwork,PointParametrizationNetworkCNN2
 from kpn import KnotPlacementNetwork
